Module audio_unit

Module audio_unit 

Structs

AudioUnitRenderActionFlags
These flags can be set in a callback from an audio unit during an audio unit render operation from either the RenderNotify Proc or the render input callback.

Type Aliases

AudioUnitElement
Type used for audio unit elements. Scopes can have one or more member, and a member of a scope is addressed / described by its element For instance, input bus 1 is input scope, element 1
AudioUnitParameterID
Type used for audio unit parameters. Parameters are typically used to control and set render state (for instance, filter cut-off frequency)
AudioUnitParameterValue
Type used for audio unit parameter values. The value of a given parameter is specified using this type (typically a Float32)
AudioUnitPropertyID
Type used for audio unit properties. Properties are used to describe the state of an audio unit (for instance, the input or output audio format)
AudioUnitScope
Type used for audio unit scopes. Apple reserves the 0 < 1024 range for audio unit scope identifiers. Scopes are used to delineate a major attribute of an audio unit (for instance, global, input, output)
Unit