AudioUnitElement

Type Alias AudioUnitElement 

pub type AudioUnitElement = u32;
Type used for audio unit elements. Scopes can have one or more member, and a member of a scope is addressed / described by its element For instance, input bus 1 is input scope, element 1

See also Apple’s documentation