CAClockArm

Function CAClockArm 

pub unsafe extern "C-unwind" fn CAClockArm(
    in_ca_clock: *mut OpaqueCAClock,
) -> i32
Allow received sync messages to start the clock.

If a clock is following and being controlled by an external transport (e.g. MIDI Time Code), call this to indicate that the client is ready to start its transport in response to the external transport having started.

The external time source will set the clock’s start position and start the clock.

Parameter inCAClock: The clock object.

Returns: An OSStatus error code.

Safety

in_ca_clock must be a valid pointer.