#[repr(transparent)]pub struct AU3DMixerRenderingFlags(pub u32);Expand description
Tuple Fields
0: u32Implementations
Sourceimpl AU3DMixerRenderingFlags
impl AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_InterAuralDelay: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_DopplerShift: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_DistanceAttenuation: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_DistanceFilter: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_DistanceDiffusion: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_LinearDistanceAttenuation: AU3DMixerRenderingFlags
pub const k3DMixerRenderingFlags_ConstantReverbBlend: AU3DMixerRenderingFlags
Sourceimpl AU3DMixerRenderingFlags
impl AU3DMixerRenderingFlags
Sourcepub const fn empty() -> AU3DMixerRenderingFlags
pub const fn empty() -> AU3DMixerRenderingFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> AU3DMixerRenderingFlags
pub const fn all() -> AU3DMixerRenderingFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<AU3DMixerRenderingFlags>
pub const fn from_bits(bits: u32) -> Option<AU3DMixerRenderingFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> AU3DMixerRenderingFlags
pub const fn from_bits_truncate(bits: u32) -> AU3DMixerRenderingFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> AU3DMixerRenderingFlags
pub const fn from_bits_retain(bits: u32) -> AU3DMixerRenderingFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AU3DMixerRenderingFlags>
pub fn from_name(name: &str) -> Option<AU3DMixerRenderingFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AU3DMixerRenderingFlags) -> bool
pub const fn intersects(&self, other: AU3DMixerRenderingFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AU3DMixerRenderingFlags) -> bool
pub const fn contains(&self, other: AU3DMixerRenderingFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AU3DMixerRenderingFlags)
pub fn insert(&mut self, other: AU3DMixerRenderingFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AU3DMixerRenderingFlags)
pub fn remove(&mut self, other: AU3DMixerRenderingFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AU3DMixerRenderingFlags)
pub fn toggle(&mut self, other: AU3DMixerRenderingFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AU3DMixerRenderingFlags, value: bool)
pub fn set(&mut self, other: AU3DMixerRenderingFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: AU3DMixerRenderingFlags,
) -> AU3DMixerRenderingFlags
pub const fn intersection( self, other: AU3DMixerRenderingFlags, ) -> AU3DMixerRenderingFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: AU3DMixerRenderingFlags,
) -> AU3DMixerRenderingFlags
pub const fn union( self, other: AU3DMixerRenderingFlags, ) -> AU3DMixerRenderingFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: AU3DMixerRenderingFlags,
) -> AU3DMixerRenderingFlags
pub const fn difference( self, other: AU3DMixerRenderingFlags, ) -> AU3DMixerRenderingFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AU3DMixerRenderingFlags,
) -> AU3DMixerRenderingFlags
pub const fn symmetric_difference( self, other: AU3DMixerRenderingFlags, ) -> AU3DMixerRenderingFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AU3DMixerRenderingFlags
pub const fn complement(self) -> AU3DMixerRenderingFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AU3DMixerRenderingFlags
impl AU3DMixerRenderingFlags
Sourcepub const fn iter(&self) -> Iter<AU3DMixerRenderingFlags>
pub const fn iter(&self) -> Iter<AU3DMixerRenderingFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AU3DMixerRenderingFlags>
pub const fn iter_names(&self) -> IterNames<AU3DMixerRenderingFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.