#[repr(C)]pub struct AUDependentParameter {
pub mScope: u32,
pub mParameterID: u32,
}Expand description
Used to represent a dependent parameter that can change as a result of its parent meta-parameter changing
See also Apple’s documentation
Fields
mScope: u32mParameterID: u32Trait Implementations
Sourceimpl Clone for AUDependentParameter
impl Clone for AUDependentParameter
Sourcefn clone(&self) -> AUDependentParameter
fn clone(&self) -> AUDependentParameter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AUDependentParameter
Sourceimpl Debug for AUDependentParameter
impl Debug for AUDependentParameter
Sourceimpl Encode for AUDependentParameter
Available on crate feature AUComponent only.
impl Encode for AUDependentParameter
Available on crate feature
AUComponent only.Sourceimpl PartialEq for AUDependentParameter
impl PartialEq for AUDependentParameter
Sourcefn eq(&self, other: &AUDependentParameter) -> bool
fn eq(&self, other: &AUDependentParameter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AUDependentParameter
Available on crate feature AUComponent only.
impl RefEncode for AUDependentParameter
Available on crate feature
AUComponent only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AUDependentParameter