#[repr(C)]pub struct AUInputSamplesInOutputCallbackStruct {
pub inputToOutputCallback: Option<unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioTimeStamp>, f64, f64)>,
pub userData: *mut c_void,
}Expand description
Used by a host when registering a callback with an audio unit, to provide input-to-output samples mapping
See also Apple’s documentation
Fields
inputToOutputCallback: Option<unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioTimeStamp>, f64, f64)>userData: *mut c_voidTrait Implementations
Sourceimpl Clone for AUInputSamplesInOutputCallbackStruct
impl Clone for AUInputSamplesInOutputCallbackStruct
Sourcefn clone(&self) -> AUInputSamplesInOutputCallbackStruct
fn clone(&self) -> AUInputSamplesInOutputCallbackStruct
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AUInputSamplesInOutputCallbackStruct
Sourceimpl Encode for AUInputSamplesInOutputCallbackStruct
Available on crate features AUComponent and objc2-core-audio-types only.
impl Encode for AUInputSamplesInOutputCallbackStruct
Available on crate features
AUComponent and objc2-core-audio-types only.Sourceimpl PartialEq for AUInputSamplesInOutputCallbackStruct
impl PartialEq for AUInputSamplesInOutputCallbackStruct
Sourcefn eq(&self, other: &AUInputSamplesInOutputCallbackStruct) -> bool
fn eq(&self, other: &AUInputSamplesInOutputCallbackStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AUInputSamplesInOutputCallbackStruct
Available on crate features AUComponent and objc2-core-audio-types only.
impl RefEncode for AUInputSamplesInOutputCallbackStruct
Available on crate features
AUComponent and objc2-core-audio-types only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AUInputSamplesInOutputCallbackStruct