#[repr(C)]pub struct AURenderCallbackStruct {
pub inputProc: Option<unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioUnitRenderActionFlags>, NonNull<AudioTimeStamp>, u32, u32, *mut AudioBufferList) -> i32>,
pub inputProcRefCon: *mut c_void,
}Expand description
Used by a host when registering a callback with the audio unit to provide input
See also Apple’s documentation
Fields
inputProc: Option<unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioUnitRenderActionFlags>, NonNull<AudioTimeStamp>, u32, u32, *mut AudioBufferList) -> i32>inputProcRefCon: *mut c_voidTrait Implementations
Sourceimpl Clone for AURenderCallbackStruct
impl Clone for AURenderCallbackStruct
Sourcefn clone(&self) -> AURenderCallbackStruct
fn clone(&self) -> AURenderCallbackStruct
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AURenderCallbackStruct
Sourceimpl Debug for AURenderCallbackStruct
impl Debug for AURenderCallbackStruct
Sourceimpl Encode for AURenderCallbackStruct
Available on crate features AUComponent and objc2-core-audio-types only.
impl Encode for AURenderCallbackStruct
Available on crate features
AUComponent and objc2-core-audio-types only.Sourceimpl PartialEq for AURenderCallbackStruct
impl PartialEq for AURenderCallbackStruct
Sourcefn eq(&self, other: &AURenderCallbackStruct) -> bool
fn eq(&self, other: &AURenderCallbackStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AURenderCallbackStruct
Available on crate features AUComponent and objc2-core-audio-types only.
impl RefEncode for AURenderCallbackStruct
Available on crate features
AUComponent and objc2-core-audio-types only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AURenderCallbackStruct