#[repr(transparent)]pub struct AudioComponentValidationResult(pub u32);Expand description
Constants for describing the result of validating an AudioComponent
The AudioComponent passed validation.
The AudioComponent failed validation.
The validation operation timed out before completing.
The AudioComponent failed validation during open operation as it is not authorized.
The AudioComponent failed validation during initialization as it is not authorized.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AudioComponentValidationResult
impl AudioComponentValidationResult
pub const Unknown: AudioComponentValidationResult
pub const Passed: AudioComponentValidationResult
pub const Failed: AudioComponentValidationResult
pub const TimedOut: AudioComponentValidationResult