#[repr(transparent)]pub struct AudioConverterOptions(pub u32);Expand description
This is an option for AudioConverterNewWithOptions which removes unnecessary buffering, both for input and internally to the converter, saving memory at the cost of reduced format support and usage restrictions:
- Input and output formats must be constant bit-rate, non-zero bytes per packet (e.g. linear PCM, a-law, etc.) with the same sample rate and frames per packet.
- AudioConverterFillBuffer cannot be used.
- AudioConverterFillComplexBuffer cannot be used.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AudioConverterOptions
impl AudioConverterOptions
pub const Unbuffered: AudioConverterOptions
Sourceimpl AudioConverterOptions
impl AudioConverterOptions
Sourcepub const fn empty() -> AudioConverterOptions
pub const fn empty() -> AudioConverterOptions
Get a flags value with all bits unset.
Sourcepub const fn all() -> AudioConverterOptions
pub const fn all() -> AudioConverterOptions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<AudioConverterOptions>
pub const fn from_bits(bits: u32) -> Option<AudioConverterOptions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> AudioConverterOptions
pub const fn from_bits_truncate(bits: u32) -> AudioConverterOptions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> AudioConverterOptions
pub const fn from_bits_retain(bits: u32) -> AudioConverterOptions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AudioConverterOptions>
pub fn from_name(name: &str) -> Option<AudioConverterOptions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AudioConverterOptions) -> bool
pub const fn intersects(&self, other: AudioConverterOptions) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AudioConverterOptions) -> bool
pub const fn contains(&self, other: AudioConverterOptions) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AudioConverterOptions)
pub fn insert(&mut self, other: AudioConverterOptions)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AudioConverterOptions)
pub fn remove(&mut self, other: AudioConverterOptions)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AudioConverterOptions)
pub fn toggle(&mut self, other: AudioConverterOptions)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AudioConverterOptions, value: bool)
pub fn set(&mut self, other: AudioConverterOptions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: AudioConverterOptions,
) -> AudioConverterOptions
pub const fn intersection( self, other: AudioConverterOptions, ) -> AudioConverterOptions
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AudioConverterOptions) -> AudioConverterOptions
pub const fn union(self, other: AudioConverterOptions) -> AudioConverterOptions
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: AudioConverterOptions,
) -> AudioConverterOptions
pub const fn difference( self, other: AudioConverterOptions, ) -> AudioConverterOptions
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AudioConverterOptions,
) -> AudioConverterOptions
pub const fn symmetric_difference( self, other: AudioConverterOptions, ) -> AudioConverterOptions
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AudioConverterOptions
pub const fn complement(self) -> AudioConverterOptions
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AudioConverterOptions
impl AudioConverterOptions
Sourcepub const fn iter(&self) -> Iter<AudioConverterOptions>
pub const fn iter(&self) -> Iter<AudioConverterOptions>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AudioConverterOptions>
pub const fn iter_names(&self) -> IterNames<AudioConverterOptions>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.