#[repr(C)]pub struct AudioUnitConnection {
pub sourceAudioUnit: *mut OpaqueAudioComponentInstance,
pub sourceOutputNumber: u32,
pub destInputNumber: u32,
}Expand description
This structure contains the information needed to make a connection between a source and destination audio unit.
The structure is set on the destination audio unit’s input element
The audio unit that is the source for the connection
The source audio unit’s output element to be used in the connection
The destination audio unit’s input element to be used in the connection
See also Apple’s documentation
Fields
sourceAudioUnit: *mut OpaqueAudioComponentInstancesourceOutputNumber: u32destInputNumber: u32Trait Implementations
Sourceimpl Clone for AudioUnitConnection
impl Clone for AudioUnitConnection
Sourcefn clone(&self) -> AudioUnitConnection
fn clone(&self) -> AudioUnitConnection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioUnitConnection
Sourceimpl Debug for AudioUnitConnection
impl Debug for AudioUnitConnection
Sourceimpl Encode for AudioUnitConnection
Available on crate features AUComponent and AudioComponent only.
impl Encode for AudioUnitConnection
Available on crate features
AUComponent and AudioComponent only.Sourceimpl PartialEq for AudioUnitConnection
impl PartialEq for AudioUnitConnection
Sourcefn eq(&self, other: &AudioUnitConnection) -> bool
fn eq(&self, other: &AudioUnitConnection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AudioUnitConnection
Available on crate features AUComponent and AudioComponent only.
impl RefEncode for AudioUnitConnection
Available on crate features
AUComponent and AudioComponent only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AudioUnitConnection