#[repr(C)]pub struct AudioUnitParameter {
pub mAudioUnit: *mut OpaqueAudioComponentInstance,
pub mParameterID: u32,
pub mScope: u32,
pub mElement: u32,
}Expand description
An audio unit parameter is defined by the triplet of audio unit scope, element and parameterID. This struct is used with the functions in AudioUnitUtilities.h to deal with audio unit parameters, but is included in this header file for completeness.
The audio unit instance to which the specified parameter applies.
The parameterID for the parameter
The scope for the parameter
The element for the parameter
See also Apple’s documentation
Fields
mAudioUnit: *mut OpaqueAudioComponentInstancemParameterID: u32mScope: u32mElement: u32Trait Implementations
Sourceimpl Clone for AudioUnitParameter
impl Clone for AudioUnitParameter
Sourcefn clone(&self) -> AudioUnitParameter
fn clone(&self) -> AudioUnitParameter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioUnitParameter
Sourceimpl Debug for AudioUnitParameter
impl Debug for AudioUnitParameter
Sourceimpl Encode for AudioUnitParameter
Available on crate feature AudioComponent only.
impl Encode for AudioUnitParameter
Available on crate feature
AudioComponent only.Sourceimpl PartialEq for AudioUnitParameter
impl PartialEq for AudioUnitParameter
Sourcefn eq(&self, other: &AudioUnitParameter) -> bool
fn eq(&self, other: &AudioUnitParameter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AudioUnitParameter
Available on crate feature AudioComponent only.
impl RefEncode for AudioUnitParameter
Available on crate feature
AudioComponent only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AudioUnitParameter