#[repr(transparent)]pub struct AudioUnitParameterOptions(pub u32);Expand description
Bit positions 18, 17, and 16 are set aside for display scales. Bit 19 is reserved.
This flag provides a hint to a host that this parameter should be controlled through the highest resolution if the host has limitations on the control resolution of parameter values. Generally this means that controlling this parameter with a single MIDI Control message (i.e. 128 values) is too course a grain for that parameter, and a finer control resolution should be used if possible. If this flag is not set, then a host can assume that a 7-bit control quantization is acceptable. Ideally, parameters should be controlled in the fullest resolution that they are published with.
Changing the parameter in real-time will cause a glitch or otherwise undesirable effect.
If set, the parameter can be ramped.
If set, the parameter is obscure (hint to UI to only display in expert mode).
In the original ParameterInfo a C string only was specified. With MacOS 10.2 and later, the last four bytes of this string are reserved for a CFStringRef, which gives the ability to used Unicode encoding, necessary for providing a name in languages using non-ASCII characters. If this flag bit is set, the CFStringRef is valid.
If set, changing this parameter may change any number of others in the AudioUnit.
If set, changing this parameter may change others in the same element as the current parameter.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AudioUnitParameterOptions
impl AudioUnitParameterOptions
pub const Flag_CFNameRelease: AudioUnitParameterOptions
pub const Flag_OmitFromPresets: AudioUnitParameterOptions
pub const Flag_PlotHistory: AudioUnitParameterOptions
pub const Flag_MeterReadOnly: AudioUnitParameterOptions
pub const Flag_DisplayMask: AudioUnitParameterOptions
pub const Flag_DisplaySquareRoot: AudioUnitParameterOptions
pub const Flag_DisplaySquared: AudioUnitParameterOptions
pub const Flag_DisplayCubed: AudioUnitParameterOptions
pub const Flag_DisplayCubeRoot: AudioUnitParameterOptions
pub const Flag_DisplayExponential: AudioUnitParameterOptions
pub const Flag_HasClump: AudioUnitParameterOptions
pub const Flag_ValuesHaveStrings: AudioUnitParameterOptions
pub const Flag_DisplayLogarithmic: AudioUnitParameterOptions
pub const Flag_IsHighResolution: AudioUnitParameterOptions
pub const Flag_NonRealTime: AudioUnitParameterOptions
pub const Flag_CanRamp: AudioUnitParameterOptions
pub const Flag_ExpertMode: AudioUnitParameterOptions
pub const Flag_HasCFNameString: AudioUnitParameterOptions
pub const Flag_IsGlobalMeta: AudioUnitParameterOptions
pub const Flag_IsElementMeta: AudioUnitParameterOptions
pub const Flag_IsReadable: AudioUnitParameterOptions
pub const Flag_IsWritable: AudioUnitParameterOptions
Sourceimpl AudioUnitParameterOptions
impl AudioUnitParameterOptions
Sourcepub const fn empty() -> AudioUnitParameterOptions
pub const fn empty() -> AudioUnitParameterOptions
Get a flags value with all bits unset.
Sourcepub const fn all() -> AudioUnitParameterOptions
pub const fn all() -> AudioUnitParameterOptions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<AudioUnitParameterOptions>
pub const fn from_bits(bits: u32) -> Option<AudioUnitParameterOptions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> AudioUnitParameterOptions
pub const fn from_bits_truncate(bits: u32) -> AudioUnitParameterOptions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> AudioUnitParameterOptions
pub const fn from_bits_retain(bits: u32) -> AudioUnitParameterOptions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AudioUnitParameterOptions>
pub fn from_name(name: &str) -> Option<AudioUnitParameterOptions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AudioUnitParameterOptions) -> bool
pub const fn intersects(&self, other: AudioUnitParameterOptions) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AudioUnitParameterOptions) -> bool
pub const fn contains(&self, other: AudioUnitParameterOptions) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AudioUnitParameterOptions)
pub fn insert(&mut self, other: AudioUnitParameterOptions)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AudioUnitParameterOptions)
pub fn remove(&mut self, other: AudioUnitParameterOptions)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AudioUnitParameterOptions)
pub fn toggle(&mut self, other: AudioUnitParameterOptions)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AudioUnitParameterOptions, value: bool)
pub fn set(&mut self, other: AudioUnitParameterOptions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: AudioUnitParameterOptions,
) -> AudioUnitParameterOptions
pub const fn intersection( self, other: AudioUnitParameterOptions, ) -> AudioUnitParameterOptions
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: AudioUnitParameterOptions,
) -> AudioUnitParameterOptions
pub const fn union( self, other: AudioUnitParameterOptions, ) -> AudioUnitParameterOptions
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: AudioUnitParameterOptions,
) -> AudioUnitParameterOptions
pub const fn difference( self, other: AudioUnitParameterOptions, ) -> AudioUnitParameterOptions
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AudioUnitParameterOptions,
) -> AudioUnitParameterOptions
pub const fn symmetric_difference( self, other: AudioUnitParameterOptions, ) -> AudioUnitParameterOptions
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AudioUnitParameterOptions
pub const fn complement(self) -> AudioUnitParameterOptions
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AudioUnitParameterOptions
impl AudioUnitParameterOptions
Sourcepub const fn iter(&self) -> Iter<AudioUnitParameterOptions>
pub const fn iter(&self) -> Iter<AudioUnitParameterOptions>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AudioUnitParameterOptions>
pub const fn iter_names(&self) -> IterNames<AudioUnitParameterOptions>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.