#[repr(C)]pub struct AudioUnitProperty {
pub mAudioUnit: *mut OpaqueAudioComponentInstance,
pub mPropertyID: u32,
pub mScope: u32,
pub mElement: u32,
}Expand description
An audio unit property is defined by the triplet of audio unit scope, element and propertyID. This struct is used with the functions in AudioUnitUtilities.h to deal with audio unit properties, but is included in this header file for completeness.
The audio unit instance which the specified property applies too
The propertyID for the property
The scope for the property
The element for the property
See also Apple’s documentation
Fields
mAudioUnit: *mut OpaqueAudioComponentInstancemPropertyID: u32mScope: u32mElement: u32Trait Implementations
Sourceimpl Clone for AudioUnitProperty
impl Clone for AudioUnitProperty
Sourcefn clone(&self) -> AudioUnitProperty
fn clone(&self) -> AudioUnitProperty
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioUnitProperty
Sourceimpl Debug for AudioUnitProperty
impl Debug for AudioUnitProperty
Sourceimpl Encode for AudioUnitProperty
Available on crate feature AudioComponent only.
impl Encode for AudioUnitProperty
Available on crate feature
AudioComponent only.Sourceimpl PartialEq for AudioUnitProperty
impl PartialEq for AudioUnitProperty
Sourcefn eq(&self, other: &AudioUnitProperty) -> bool
fn eq(&self, other: &AudioUnitProperty) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AudioUnitProperty
Available on crate feature AudioComponent only.
impl RefEncode for AudioUnitProperty
Available on crate feature
AudioComponent only.Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for AudioUnitProperty