#[repr(transparent)]pub struct AudioUnitRenderActionFlags(pub u32);Expand description
These flags can be set in a callback from an audio unit during an audio unit render operation from either the RenderNotify Proc or the render input callback.
Called on a render notification Proc - which is called either before or after the render operation of the audio unit. If this flag is set, the proc is being called before the render operation is performed.
Called on a render notification Proc - which is called either before or after the render operation of the audio unit. If this flag is set, the proc is being called after the render operation is completed.
The originator of a buffer, in a render input callback, or in an audio unit’s render operation, may use this flag to indicate that the buffer contains only silence.
The receiver of the buffer can then use the flag as a hint as to whether the buffer needs to be processed or not.
Note that because the flag is only a hint, when setting the silence flag, the originator of a buffer must also ensure that it contains silence (zeroes).
This is used with offline audio units (of type ‘auol’). It is used when an offline unit is being preflighted, which is performed prior to the actual offline rendering actions are performed. It is used for those cases where the offline process needs it (for example, with an offline unit that normalises an audio file, it needs to see all of the audio data first before it can perform its normalization)
Once an offline unit has been successfully preflighted, it is then put into its render mode. So this flag is set to indicate to the audio unit that it is now in that state and that it should perform its processing on the input data.
This flag is set when an offline unit has completed either its preflight or performed render operations
If this flag is set on the post-render call an error was returned by the AUs render operation. In this case, the error can be retrieved through the lastRenderError property and the audio data in ioData handed to the post-render notification will be invalid.
If this flag is set, then checks that are done on the arguments provided to render are not performed. This can be useful to use to save computation time in situations where you are sure you are providing the correct arguments and structures to the various render calls
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AudioUnitRenderActionFlags
impl AudioUnitRenderActionFlags
pub const UnitRenderAction_PreRender: AudioUnitRenderActionFlags
pub const UnitRenderAction_PostRender: AudioUnitRenderActionFlags
pub const UnitRenderAction_OutputIsSilence: AudioUnitRenderActionFlags
pub const OfflineUnitRenderAction_Preflight: AudioUnitRenderActionFlags
pub const OfflineUnitRenderAction_Render: AudioUnitRenderActionFlags
pub const OfflineUnitRenderAction_Complete: AudioUnitRenderActionFlags
pub const UnitRenderAction_PostRenderError: AudioUnitRenderActionFlags
pub const UnitRenderAction_DoNotCheckRenderArgs: AudioUnitRenderActionFlags
Sourceimpl AudioUnitRenderActionFlags
impl AudioUnitRenderActionFlags
Sourcepub const fn empty() -> AudioUnitRenderActionFlags
pub const fn empty() -> AudioUnitRenderActionFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> AudioUnitRenderActionFlags
pub const fn all() -> AudioUnitRenderActionFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<AudioUnitRenderActionFlags>
pub const fn from_bits(bits: u32) -> Option<AudioUnitRenderActionFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> AudioUnitRenderActionFlags
pub const fn from_bits_truncate(bits: u32) -> AudioUnitRenderActionFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> AudioUnitRenderActionFlags
pub const fn from_bits_retain(bits: u32) -> AudioUnitRenderActionFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AudioUnitRenderActionFlags>
pub fn from_name(name: &str) -> Option<AudioUnitRenderActionFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AudioUnitRenderActionFlags) -> bool
pub const fn intersects(&self, other: AudioUnitRenderActionFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AudioUnitRenderActionFlags) -> bool
pub const fn contains(&self, other: AudioUnitRenderActionFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AudioUnitRenderActionFlags)
pub fn insert(&mut self, other: AudioUnitRenderActionFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AudioUnitRenderActionFlags)
pub fn remove(&mut self, other: AudioUnitRenderActionFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AudioUnitRenderActionFlags)
pub fn toggle(&mut self, other: AudioUnitRenderActionFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AudioUnitRenderActionFlags, value: bool)
pub fn set(&mut self, other: AudioUnitRenderActionFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: AudioUnitRenderActionFlags,
) -> AudioUnitRenderActionFlags
pub const fn intersection( self, other: AudioUnitRenderActionFlags, ) -> AudioUnitRenderActionFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: AudioUnitRenderActionFlags,
) -> AudioUnitRenderActionFlags
pub const fn union( self, other: AudioUnitRenderActionFlags, ) -> AudioUnitRenderActionFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: AudioUnitRenderActionFlags,
) -> AudioUnitRenderActionFlags
pub const fn difference( self, other: AudioUnitRenderActionFlags, ) -> AudioUnitRenderActionFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AudioUnitRenderActionFlags,
) -> AudioUnitRenderActionFlags
pub const fn symmetric_difference( self, other: AudioUnitRenderActionFlags, ) -> AudioUnitRenderActionFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AudioUnitRenderActionFlags
pub const fn complement(self) -> AudioUnitRenderActionFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AudioUnitRenderActionFlags
impl AudioUnitRenderActionFlags
Sourcepub const fn iter(&self) -> Iter<AudioUnitRenderActionFlags>
pub const fn iter(&self) -> Iter<AudioUnitRenderActionFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AudioUnitRenderActionFlags>
pub const fn iter_names(&self) -> IterNames<AudioUnitRenderActionFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.