#[repr(transparent)]pub struct CAClockMessage(pub u32);Expand description
The messages sent to a CAClockListenerProc to notify the client of changes to the clock’s state.
A new start time was set or received from an external sync source.
The clock’s time has started moving.
The clock’s time has stopped moving.
The client has called CAClockArm().
The client has called CAClockDisarm().
A clock property has been changed.
The clock is receiving SMPTE (MTC) messages in a SMPTE format that does not match the clock’s SMPTE format.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl CAClockMessage
impl CAClockMessage
pub const StartTimeSet: CAClockMessage
pub const Started: CAClockMessage
pub const Stopped: CAClockMessage
pub const Armed: CAClockMessage
pub const Disarmed: CAClockMessage
pub const PropertyChanged: CAClockMessage
pub const WrongSMPTEFormat: CAClockMessage