#[repr(transparent)]pub struct CAClockPropertyID(pub u32);Expand description
The properties of a CoreAudioClock, accessible via CAClockGetProperty and CAClockSetProperty.
Type: CAClockTimebase. Selects the internal time reference for the clock (currently, host time, an audio device, or audio output unit).
Type: according to the internal timebase. If the timebase is kCAClockTimebase_AudioDevice, the value is an AudioDeviceID. For kCAClockTimebase_AudioOutputUnit, the value is an AudioUnit.
Type: CAClockSyncMode. Selects between internal synchronization and multiple external synchronization modes such as MIDI Time Code and MIDI beat clock.
Type: according to the sync mode. For kCAClockSyncMode_MIDIClockTransport or kCAClockSyncMode_MTCTransport, the value is a MIDIEndpointRef.
Type: CAClockSMPTEFormat. Specifies the SMPTE format (fps, drop or non-drop) expected for received SMPTE messages, and used for transmitted SMPTE messages and SMPTE time representations.
Type: CAClockSeconds. The SMPTE time, represented in seconds since 00:00:00:00, corresponding to a timeline position of 0 seconds.
Type: array of MIDIEndpointRef. When non-empty, the clock will transmit MIDI beat clock to the MIDI endpoints in this list. (As of macOS 10.6, the endpoints may be virtual sources. Previously, they had to be destinations.)
Type: array of MIDIEndpointRef. When non-empty, the clock will transmit MIDI Time Code to the MIDI endpoints in this list. (As of macOS 10.6, the endpoints may be virtual sources. Previously, they had to be destinations.)
Type: CAClockSeconds. When the sync mode is MIDI Time Code, this controls how long the reader will keep running after the last MTC message is received before stopping (default: 1 sec). Should be at least ~4 SMPTE frames in duration.
Type: array of CATempoMapEntry. Specifies a tempo map for the clock, defining the relationship between timeline positions in seconds and musical beats. Defaults to a constant tempo of 120 bpm.
Type: array of CAMeterTrackEntry. Specifies the positions of musical time signature changes in the timeline. Used only for converting between beats and CABarBeatTime’s (a display representation of a beat time).
Type: CFStringRef. Sets a name for the clock. When a client sets the property, the clock retains a reference to the string. When a client gets the property, it receives a borrowed reference (i.e. the client must not release the string).
Type: UInt32. Specifies whether MIDI Song Position Pointer messages are sent to the clock’s MIDI clock destinations (if any). Available starting in macOS 10.6.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl CAClockPropertyID
impl CAClockPropertyID
pub const InternalTimebase: CAClockPropertyID
pub const TimebaseSource: CAClockPropertyID
pub const SyncMode: CAClockPropertyID
pub const SyncSource: CAClockPropertyID
pub const SMPTEFormat: CAClockPropertyID
pub const SMPTEOffset: CAClockPropertyID
pub const MIDIClockDestinations: CAClockPropertyID
pub const MTCDestinations: CAClockPropertyID
pub const MTCFreewheelTime: CAClockPropertyID
pub const TempoMap: CAClockPropertyID
pub const MeterTrack: CAClockPropertyID
pub const Name: CAClockPropertyID
pub const SendMIDISPP: CAClockPropertyID