#[repr(C)]pub struct HostCallbackInfo {
pub hostUserData: *mut c_void,
pub beatAndTempoProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut f64, *mut f64) -> i32>,
pub musicalTimeLocationProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u32, *mut f32, *mut u32, *mut f64) -> i32>,
pub transportStateProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u8, *mut u8, *mut f64, *mut u8, *mut f64, *mut f64) -> i32>,
pub transportStateProc2: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u8, *mut u8, *mut u8, *mut f64, *mut u8, *mut f64, *mut f64) -> i32>,
}Expand description
Contains the various callbacks for an audio unit to call
Any callback can be NULL.
See also Apple’s documentation
Fields
hostUserData: *mut c_voidbeatAndTempoProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut f64, *mut f64) -> i32>musicalTimeLocationProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u32, *mut f32, *mut u32, *mut f64) -> i32>transportStateProc: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u8, *mut u8, *mut f64, *mut u8, *mut f64, *mut f64) -> i32>transportStateProc2: Option<unsafe extern "C-unwind" fn(*mut c_void, *mut u8, *mut u8, *mut u8, *mut f64, *mut u8, *mut f64, *mut f64) -> i32>Trait Implementations
Sourceimpl Clone for HostCallbackInfo
impl Clone for HostCallbackInfo
Sourcefn clone(&self) -> HostCallbackInfo
fn clone(&self) -> HostCallbackInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for HostCallbackInfo
Sourceimpl Debug for HostCallbackInfo
impl Debug for HostCallbackInfo
Sourceimpl Encode for HostCallbackInfo
impl Encode for HostCallbackInfo
Sourceimpl PartialEq for HostCallbackInfo
impl PartialEq for HostCallbackInfo
Sourcefn eq(&self, other: &HostCallbackInfo) -> bool
fn eq(&self, other: &HostCallbackInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for HostCallbackInfo
impl RefEncode for HostCallbackInfo
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl StructuralPartialEq for HostCallbackInfo