pub type AudioUnitParameterValue = f32;Expand description
Type used for audio unit parameter values. The value of a given parameter is specified using this type (typically a Float32)
See also Appleās documentation
pub type AudioUnitParameterValue = f32;Type used for audio unit parameter values. The value of a given parameter is specified using this type (typically a Float32)
See also Appleās documentation