pub type AudioUnitPropertyID = u32;Expand description
Type used for audio unit properties. Properties are used to describe the state of an audio unit (for instance, the input or output audio format)
See also Appleās documentation
pub type AudioUnitPropertyID = u32;Type used for audio unit properties. Properties are used to describe the state of an audio unit (for instance, the input or output audio format)
See also Appleās documentation