These flags can be set in a callback from an audio unit during an audio unit
render operation from either the RenderNotify Proc or the render input
callback.
Type used for audio unit elements.
Scopes can have one or more member, and a member of a scope is
addressed / described by its element
For instance, input bus 1 is input scope, element 1
Type used for audio unit scopes. Apple reserves the 0
<
1024 range for
audio unit scope identifiers.
Scopes are used to delineate a major attribute of an audio unit
(for instance, global, input, output)