pub unsafe extern "C-unwind" fn AudioConverterGetPropertyInfo(
in_audio_converter: *mut OpaqueAudioConverter,
in_property_id: u32,
out_size: *mut u32,
out_writable: *mut u8,
) -> i32Expand description
Returns information about an AudioConverter property.
Parameter inAudioConverter: The AudioConverter to query.
Parameter inPropertyID: The property to query.
Parameter outSize: If non-null, on exit, the maximum size of the property value in bytes.
Parameter outWritable: If non-null, on exit, indicates whether the property value is writable.
Returns: An OSStatus result code.
Safety
in_audio_convertermust be a valid pointer.out_sizemust be a valid pointer or null.out_writablemust be a valid pointer or null.